| z22_grid | R Documentation |
Retrieve the entire INSPIRE grid.
Unlike the feature grids retrieved from z22_data,
the INSPIRE grid encompasses the entire area of Germany. You can thus use
it to join with the incomplete feature grids from z22_data
to create a complete dataset.
z22_grid(res, year = 2019, as = c("df", "sf", "raster"), update_cache = FALSE)
res |
Resolution of the grid. Can be |
year |
Version of the grid. Can be 2015, 2017, 2018 and 2019. Defaults to the latest version. |
as |
Specifies the output class. Must be one of |
update_cache |
By default, both functions cache attribute files for
the remainder of the R session. They are downloaded to a temporary directory
and - if the file to download already exists - are recovered from the cache.
In other words, when rerunning the same request multiple times, the
subsequent calls should be much faster. If |
Note the uncompressed object sizes of the output (2019 version):
100 m: 38 million cells, 291 MB
250 m: 6 million cells, 47 MB
1 km: 384 thousand cells, 3 MB
5 km: 16 thousand cells, 0.12 MB
10 km: 4 thousand cells, 0.03 MB
A tibble, SpatRaster or
sf tibble depending on the as argument.
# Get high-res grid as tibble
z22_grid("100m")
# Get low-res grid as raster
z22_grid("1km", as = "raster")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.